/**
 * Copyright (C) 2008  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.console.navigation;

import org.exoplatform.container.PortalContainer;
import org.exoplatform.services.organization.Membership;

/**
 * The MembershipEventListener is triggered by the event of adding or removing
 * membership for a user. It allow to update the user pages and the accessible
 * applications according to his new profile.
 * 
 * @author Elwalid Brahim <elwalid.brahim@bull.net>
 */
public class NovaMembershipEventListener extends org.exoplatform.services.organization.MembershipEventListener {

  @Override
  public void postSave(Membership m, boolean isNew) throws Exception {
    super.postSave(m, isNew);
    /* Get the console pages management service */
    PortalContainer portalContainer = PortalContainer.getInstance();
    ConsolePagesManagementService consolePagesManagementService = (ConsolePagesManagementService) portalContainer
        .getComponentInstanceOfType(ConsolePagesManagementService.class);

    /* Update the new user pages according to the new added membership */
    consolePagesManagementService.updateUserPages(m);
  }

  @Override
  public void postDelete(Membership m) throws Exception {
    super.postDelete(m);
    /* Get the console pages management service */
    PortalContainer portalContainer = PortalContainer.getInstance();
    ConsolePagesManagementService consolePagesManagementService = (ConsolePagesManagementService) portalContainer
        .getComponentInstanceOfType(ConsolePagesManagementService.class);

    /*
     * Delete the applications that becomes not accessible cause the given
     * membership was deleted
     */
    consolePagesManagementService.deleteUserApplications(m);
  }

}
